@@ -1,5 +1,5 @@
 from .agents import *
-from .rpc import *
+from .postman import *
 from .comfort import *
 from .monitor import *
 from .schema.widgets import *
\ No newline at end of file
