@@ -1,4 +1,5 @@
-from qtpy import QtWidgets, QtGui, QtCore
+from qtpy import QtWidgets, QtGui
+from arkitekt.qt.images.dir import get_image_path
 from arkitekt.qt.widgets.settings_popup import SettingsPopup
 from fakts.qt import QtFakts
 from herre.qt import QtHerre
@@ -9,9 +10,10 @@ import traceback
 class MagicBar(QtWidgets.QWidget):
     settingsPopupClass = SettingsPopup
 
-    def __init__(self, fakts: QtFakts, herre: QtHerre, agent: QtAgent, *args, parent=None, **kwargs) -> None:
+    def __init__(self, fakts: QtFakts, herre: QtHerre, agent: QtAgent, *args, parent=None, darkMode=False, **kwargs) -> None:
         super().__init__(*args, parent=parent,**kwargs)
 
+        self.darkMode = darkMode
         self.fakts = fakts
         self.herre = herre
         self.agent = agent
@@ -26,15 +28,23 @@ class MagicBar(QtWidgets.QWidget):
         self.agent_provide_task = None
 
         #Settings
-        self.gear_button_popup = self.settingsPopupClass(self, parent=parent)
-
-
-        self.layout = QtWidgets.QHBoxLayout()
-        self.gearb = QtWidgets.QToolButton()
-        self.gearb.setIcon(QtGui.QIcon("gear.png"))
+        self.gear_button_popup = self.settingsPopupClass(self)
 
 
         self.magicb = QtWidgets.QPushButton("Connect")
+        self.magicb.setMinimumHeight(30)
+        self.magicb.setMaximumHeight(30)
+
+        self.layout = QtWidgets.QHBoxLayout()
+        self.gearb_pix = QtGui.QPixmap(get_image_path("gear.png", darkMode=darkMode))
+        self.gearb = QtWidgets.QPushButton()
+        self.gearb.setIcon(QtGui.QIcon(self.gearb_pix))
+        self.gearb.setMinimumWidth(30)
+        self.gearb.setMaximumWidth(30)
+        self.gearb.setMinimumHeight(30)
+        self.gearb.setMaximumHeight(30)
+
+
         self.layout.addWidget(self.magicb)
         self.layout.addWidget(self.gearb)
         self.setLayout(self.layout)
@@ -85,6 +95,7 @@ class MagicBar(QtWidgets.QWidget):
 
 
     def gear_button_clicked(self):
+        print("Gear Button Clicked")
         self.gear_button_popup.show()
 
     def magic_button_clicked(self):
@@ -122,35 +133,35 @@ class MagicBar(QtWidgets.QWidget):
         self.magicb.setIcon(QtGui.QIcon(self.magicb_movie.currentPixmap()))
 
     def set_unkonfigured(self):
-        self.magicb_movie = QtGui.QMovie("pink pulse.gif")
+        self.magicb_movie = QtGui.QMovie(get_image_path("pink pulse.gif", darkMode=self.darkMode))
         self.magicb_movie.frameChanged.connect(self.update_movie)
         self.magicb_movie.start()
 
         self.magicb.setText("Konfigure App")
 
     def set_unconnected(self):
-        self.magicb_movie = QtGui.QMovie("green pulse.gif")
+        self.magicb_movie = QtGui.QMovie(get_image_path("green pulse.gif", darkMode=self.darkMode))
         self.magicb_movie.frameChanged.connect(self.update_movie)
         self.magicb_movie.start()
 
         self.magicb.setText("Connect")
 
     def set_halted(self):
-        self.magicb_movie = QtGui.QMovie("pink pulse.gif")
+        self.magicb_movie = QtGui.QMovie(get_image_path("orange pulse.gif", darkMode=self.darkMode))
         self.magicb_movie.frameChanged.connect(self.update_movie)
         self.magicb_movie.start()
 
         self.magicb.setText("Halted")
 
     def set_unprovided(self):
-        self.magicb_movie = QtGui.QMovie("green pulse.gif")
+        self.magicb_movie = QtGui.QMovie(get_image_path("green pulse.gif", darkMode=self.darkMode))
         self.magicb_movie.frameChanged.connect(self.update_movie)
         self.magicb_movie.start()
 
         self.magicb.setText("Provide")
 
     def set_providing(self):
-        self.magicb_movie = QtGui.QMovie("green pulse.gif")
+        self.magicb_movie = QtGui.QMovie(get_image_path("green pulse.gif", darkMode=self.darkMode))
         self.magicb_movie.frameChanged.connect(self.update_movie)
         self.magicb_movie.start()
 
